<template>
    <div class="bg-white relative grid grid-cols-3 gap-2 px-4 py-3 overflow-hidden">
        <div
                v-for="(tab) in useChatList.tabs"
                :key="tab.id"
                @click.prevent="changeTab(tab.id)"
                :class="`${tab.id === useChatList.tabName ? 'bg-scheme-primary text-white hover:bg-opacity-80' : 'hover:bg-opacity-20 text-gray-500'} relative text-center block py-3 px-2 rounded-lg transition duration-300 hover:bg-scheme-primary cursor-pointer text-xs font-semibold border shadow`"
        >
            {{ tab.name }}
            <span v-if="general.chatTab == 'whatsapp'" v-show="useChatList.unreadCount[tab.id.toLowerCase()] > 0"
                  class="absolute -top-2 z-50 -right-2 bg-blue-100 text-blue-800 text-xs font-medium px-2 py-0.5 rounded-full dark:bg-blue-900 dark:text-blue-300">{{
                useChatList.unreadCount[tab.id.toLowerCase()]
                }}</span>
        </div>
    </div>
</template>

<script setup lang="ts">

import {useChatListStore} from "../../stores/chat_list";
import {onMounted, ref, watch} from "vue";
import {useGeneralStore} from "../../stores/general";

/**
 * Call Chat List from State
 */
const useChatList = useChatListStore()
const general = useGeneralStore()
const currentChatTab = ref('whatsapp')

watch(() => general.chatTab, (val) => {
  currentChatTab.value = val
})

/**
 * Watching Tab change & Fetch chat list by selected tab
 */
watch(() => useChatList.tabName, (value, oldValue, onCleanup) => {
    if (value !== oldValue) {
      useChatList.resetPage()
        // useChatList.isEndPage = false
        // useChatList.currentPage = 1
        const storage = localStorage.getItem("filter_label")
        if (storage) {
            const storageDc = JSON.parse(storage)
            if (storageDc && Array.isArray(storageDc)) {
                if (storageDc.length > 0) {
                    useChatList.isLabelFiltered = true
                    useChatList.selectedLabel = storageDc
                    useChatList.filterChatListByLabels(value, useChatList.filterData, useChatList.chatListPerPage, 1,true, currentChatTab.value)
                    
                } else {
                    useChatList.isLabelFiltered = false
                    useChatList.selectedLabel = []
                    if(useChatList.isListFiltered){
                      useChatList.filterChatListByLabels(value, useChatList.filterData, useChatList.chatListPerPage, 1,true, currentChatTab.value)
                    }else{                   
                      useChatList.fetchChatListByGroup(useChatList.tabName, true,{
                        name: useChatList.searchString
                      })
                    }
                }
            } else {
                useChatList.isLabelFiltered = false
                useChatList.selectedLabel = []
                if(useChatList.isListFiltered){
                  useChatList.filterChatListByLabels(value, useChatList.filterData, useChatList.chatListPerPage, 1,true, currentChatTab.value)
                }else{                   
                  useChatList.fetchChatListByGroup(useChatList.tabName, true,{
                    name: useChatList.searchString
                  })
                }
            }
        } else {
            useChatList.isLabelFiltered = false
            useChatList.selectedLabel = []
            if(useChatList.isListFiltered){
              useChatList.filterChatListByLabels(value, useChatList.filterData, useChatList.chatListPerPage, 1,true, currentChatTab.value)
            }else{                   
              useChatList.fetchChatListByGroup(useChatList.tabName, true,{
                name: useChatList.searchString
              })
            }
        }
        // localStorage.setItem("filter_label", JSON.stringify([]))
    }
})

/**
 * Watching Tab change & Fetch chat list by selected tab
 */
watch(() => useChatList.tabUnread, (value, oldValue, onCleanup) => {
    return value
})

onMounted(async () => {

})
watch(() => general.token, async (val) => {
  if (val) {
    await useChatList.getUnreadCount()
  }
})
/**
 * Tab on click handler
 * @param tab
 */
const changeTab = (tab) => {
    useChatList.setChatTab(tab)
}
</script>
